@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::PerinciCmdLine;
 
 our $DATE = '2015-08-26'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -31,9 +31,9 @@ sub weave_section {
 
     my $text;
     if ($res->[3]{'func.is_inline'}) {
-        $self->section_text_has_completion({command_name=>$command_name});
+        $text = $self->section_text_has_completion({command_name=>$command_name});
     } else {
-        $self->section_text_self_completion({command_name=>$command_name});
+        $text = $self->section_text_self_completion({command_name=>$command_name});
     }
 
     $self->add_text_to_section($document, $text, 'COMPLETION');
@@ -55,7 +55,7 @@ Pod::Weaver::Section::Completion::PerinciCmdLine - Add a COMPLETION section for
 
 =head1 VERSION
 
-This document describes version 0.12 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2015-08-26.
+This document describes version 0.13 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2015-08-26.
 
 =head1 SYNOPSIS
 
